const config = require('./config.json');

const reversDate = (value = '') => `${value.slice(4, 6)}${value.slice(2, 4)}${value.slice(0, 2)}`;

const completeExpirationDate = (year, prefix) => `${prefix}${year}`;

const completeExpirationDateByAge = (year, ageOption, ageProcessed) => (ageProcessed >= ageOption && year?.startsWith('99') ? completeExpirationDate(year, '99') : year);

const normalizers = {
  reversDate: () => (date) => reversDate(date),
  completeExpirationDate: (prefix) => (year) => completeExpirationDate(year, prefix),
  completeExpirationDateByAge: (ageOption) => (year, ageProcessed) => (
    completeExpirationDateByAge(year, ageOption, ageProcessed)),
  default: () => (date) => date,
};

const normalizeExpirationDate = (countryCode, documentType, date, ...args) => {
  const normalizer = config[countryCode]?.[documentType]?.normalizer || 'default';
  const configArgs = config[countryCode]?.[documentType]?.args || [];
  return normalizers[normalizer](...configArgs)(date, ...args);
};

module.exports = normalizeExpirationDate;
