import Service, { Context } from '@vorld/base-service';
import { parseMrz, normalizeMrzByOcr } from './controllers';
import { MrzParseRequest } from './MrzParseRequest';
import { NormalizeRequest } from './NormalizeRequest';

const service = new Service('mrz-parser-v2', process.env.GETID_SRV_BUILD_VERSION || 'unknown', __dirname);
service.startHttpTransport(8080);

service.addHandler(MrzParseRequest, '/parse', async (ctx: Context, data: MrzParseRequest) => await parseMrz(ctx, data));

service.addHandler(NormalizeRequest, '/normalize', async (ctx: Context, data: NormalizeRequest) => ({
  categories: await normalizeMrzByOcr(ctx, data),
}));

service.setReadiness(async () => ({ status: 200, message: 'Service ready' }));
service.setLiveness(async () => ({ status: 200, message: 'Service live' }));
