const parse = require('../parse');

describe('parse Poland TD1', () => {
  it('poland TD1 - valid with personal number', () => {
    const data = [
      'I<POLDAG2982572<<<<<<<<<<<<<<<', '9308075F2905202POL930807067602', 'PLUSA<<EMILIA<MAGDALENA<<<<<<<',
    ];

    const result = parse(data);
    expect(result).toMatchObject({
      format: 'POLAND_TD1',
      valid: true,
    });
    expect(result.fields).toStrictEqual({
      documentCode: 'I',
      issuingState: 'POL',
      documentNumber: 'DAG298257',
      documentNumberCheckDigit: '2',
      optional1: '',
      birthDate: '930807',
      birthDateCheckDigit: '5',
      sex: 'female',
      expirationDate: '290520',
      expirationDateCheckDigit: '2',
      nationality: 'POL',
      personalNumber: '93080706760',
      compositeCheckDigit: '2',
      lastName: 'PLUSA',
      firstName: 'EMILIA MAGDALENA',
    });
  });

  it('poland TD1 - valid without personal number', () => {
    const data = [
      'I<POLAVM1189682<<<<<<<<<<<<<<<', '9409097F2209128POL<<<<<<<<<<<4', 'FILIPCZAK<<MARTA<PATRYCJA<<<<<',
    ];

    const result = parse(data);
    expect(result).toMatchObject({
      format: 'POLAND_TD1',
      valid: true,
    });
    expect(result.fields).toStrictEqual({
      documentCode: 'I',
      issuingState: 'POL',
      documentNumber: 'AVM118968',
      documentNumberCheckDigit: '2',
      optional1: '',
      birthDate: '940909',
      birthDateCheckDigit: '7',
      sex: 'female',
      expirationDate: '220912',
      expirationDateCheckDigit: '8',
      nationality: 'POL',
      personalNumber: '',
      compositeCheckDigit: '4',
      lastName: 'FILIPCZAK',
      firstName: 'MARTA PATRYCJA',
    });
  });
});
