const parse = require('../parse');

describe('parse DOMINICAN_TD1 kuwait', () => {
  it('example 1', () => {
    const data = [
      'IDDOM402005655<845<<<<<<<<<<<<', '9607239M2407234DOM<<<<<<<<<<<3', 'PANIAGUA<GERMAN<<FELIX<ANTONIO',
    ];

    const result = parse(data);

    expect(result.fields).toStrictEqual({
      documentCode: 'ID',
      issuingState: 'DOM',
      documentNumber: '40200565584',
      documentNumberCheckDigit: '5',
      optional1: '',
      birthDate: '960723',
      birthDateCheckDigit: '9',
      sex: 'male',
      expirationDate: '240723',
      expirationDateCheckDigit: '4',
      nationality: 'DOM',
      optional2: '',
      lastName: 'PANIAGUA GERMAN',
      firstName: 'FELIX ANTONIO',
    });

    expect(result).toMatchObject({
      format: 'DOMINICAN_TD1',
      valid: true,
    });
  });

  it('example 2', () => {
    const MRZ = [
      'IDDOM229000565<777<<<<<<<<<<<<', '8702115M2402114DOM<<<<<<<<<<<5', 'JAVIER<HENRIQUEZ<<LUIS<CARLOS<',
    ];

    const result = parse(MRZ);
    expect(result.fields).toStrictEqual({
      documentCode: 'ID',
      issuingState: 'DOM',
      documentNumber: '22900056577',
      documentNumberCheckDigit: '7',
      optional1: '',
      birthDate: '870211',
      birthDateCheckDigit: '5',
      sex: 'male',
      expirationDate: '240211',
      expirationDateCheckDigit: '4',
      nationality: 'DOM',
      optional2: '',
      lastName: 'JAVIER HENRIQUEZ',
      firstName: 'LUIS CARLOS',
    });

    expect(result).toMatchObject({
      format: 'DOMINICAN_TD1',
      valid: true,
    });
  });

  it('example 3', () => {
    const MRZ = [
      'IDDOM003011847<439<<<<<<<<<<<<', '9208038M2408035DOM<<<<<<<<<<<5', 'CONTRERAS<VALDEZ<<FEDERICO<<<<',
    ];

    const result = parse(MRZ);
    expect(result.fields).toStrictEqual({
      documentCode: 'ID',
      issuingState: 'DOM',
      documentNumber: '00301184743',
      documentNumberCheckDigit: '9',
      optional1: '',
      birthDate: '920803',
      birthDateCheckDigit: '8',
      sex: 'male',
      expirationDate: '240803',
      expirationDateCheckDigit: '5',
      nationality: 'DOM',
      optional2: '',
      lastName: 'CONTRERAS VALDEZ',
      firstName: 'FEDERICO',
    });

    expect(result).toMatchObject({
      format: 'DOMINICAN_TD1',
      valid: true,
    });
  });
});
