const parse = require('../parse');

describe('parse Ecuador TD1', () => {
  describe('card version 1', () => {
    it('document number v1', () => {
      const data = [
        'IDECU1111111111<<<<<<<<<<<<<<<',
        '000000M000000ECU<<<<<<<<<<<<<<',
        'AAAAAA<AAAA<<AAAAAA<AAAAAAA<<<',
      ];

      const result = parse(data);
      const { documentNumber } = result?.fields;

      expect(documentNumber).toEqual('1111111111');
    });

    it('sex male v1', () => {
      const data = [
        'IDECU1111111111<<<<<<<<<<<<<<<',
        '000000M000000ECU<<<<<<<<<<<<<<',
        'AAAAAA<AAAA<<AAAAAA<AAAAAAA<<<',
      ];

      const result = parse(data);
      const { sex } = result?.fields;

      expect(sex).toEqual('male');
    });

    it('sex female v1', () => {
      const data = [
        'IDECU1111111111<<<<<<<<<<<<<<<',
        '000000F000000ECU<<<<<<<<<<<<<<',
        'AAAAAAAA<AAAAAAA<<AAAAA<AAAAAA',
      ];

      const result = parse(data);
      const { sex } = result?.fields;

      expect(sex).toEqual('female');
    });
  });

  describe('card version 2', () => {
    it('document number v2', () => {
      const data = [
        'IDECU123456789<00<<<<<<<<<<<<<',
        '0000000M0000000ECU<<<<<<<<<<<2',
        'AAAAAAA<AAAAAAAA<<AAAAAAA<AAAA',
      ];

      const result = parse(data);
      const { documentNumber } = result?.fields;

      expect(documentNumber).toEqual('1234567890');
    });

    it('sex male v2', () => {
      const data = [
        'IDECU123456789<00<<<<<<<<<<<<<',
        '0000000M0000000ECU<<<<<<<<<<<2',
        'AAAAAAA<AAAAAAAA<<AAAAAAA<AAAA',
      ];

      const result = parse(data);
      const { sex } = result?.fields;

      expect(sex).toEqual('male');
    });
  });

  describe('card version 3', () => {
    it('sex female v3', () => {
      const data = [
        'IDECU1111111111<<<<<<<<<<<<<<<',
        '19880314F000000ECU<<<<<<<<<<<<',
        'AAAAAAAA<AAAAAAA<<AAAAA<AAAAAA',
      ];

      const result = parse(data);
      const { sex } = result?.fields;

      expect(sex).toEqual('female');
    });
  });

  describe('date of birth', () => {
    it('8-digit format', () => {
      const data = [
        'IDECU1111111111<<<<<<<<<<<<<<<',
        '19880314F000000ECU<<<<<<<<<<<<',
        'AAAAAAAA<AAAAAAA<<AAAAA<AAAAAA',
      ];

      const result = parse(data);
      const { birthDate } = result?.fields;

      expect(birthDate).toEqual('880314');
    });

    it('7-digit format', () => {
      const data = [
        'IDECU1111111111<<<<<<<<<<<<<<<',
        '7612219F000000ECU<<<<<<<<<<<<<',
        'AAAAAAAA<AAAAAAA<<AAAAA<AAAAAA',
      ];

      const result = parse(data);
      const { birthDate } = result?.fields;

      expect(birthDate).toEqual('761221');
    });

    it('6-digit format', () => {
      const data = [
        'IDECU1111111111<<<<<<<<<<<<<<<',
        '640206F000000ECU<<<<<<<<<<<<<<',
        'AAAAAAAA<AAAAAAA<<AAAAA<AAAAAA',
      ];

      const result = parse(data);
      const { birthDate } = result?.fields;

      expect(birthDate).toEqual('640206');
    });
  });
});
