const parse = require('../parse');

describe('parse TD1 kuwait', () => {
  it('example 1', () => {
    const data = [
      'IDKWTJ830838324292093000487<<<', '9209301M2202163IRN15377089<<<6', 'BAKHTIARI<<MORAD<<<<<<<<<<<<<<',
    ];

    const result = parse(data);
    expect(result).toMatchObject({
      format: 'KUWAIT_TD1',
      valid: true,
    });
    expect(result.fields).toStrictEqual({
      documentCode: 'ID',
      issuingState: 'KWT',
      documentNumber: 'J83083832',
      documentNumberCheckDigit: '4',
      personalNumber: '292093000487',
      optional1: '292093000487',
      birthDate: '920930',
      birthDateCheckDigit: '1',
      sex: 'male',
      expirationDate: '220216',
      expirationDateCheckDigit: '3',
      nationality: 'IRN',
      optional2: '15377089',
      lastName: 'BAKHTIARI',
      firstName: 'MORAD',
    });
  });

  it('example 2', () => {
    const MRZ = [
      'IDKWTA235242248297111500358<<<', '9711150M2411255KWT19829871<<<2', 'ALSUWAILEM<<ABDULLAH<<<<<<<<<<',
    ];

    const result = parse(MRZ);
    expect(result).toMatchObject({
      format: 'KUWAIT_TD1',
      valid: true,
    });
    expect(result.fields).toStrictEqual({
      documentCode: 'ID',
      issuingState: 'KWT',
      documentNumber: 'A23524224',
      documentNumberCheckDigit: '8',
      personalNumber: '297111500358',
      optional1: '297111500358',
      birthDate: '971115',
      birthDateCheckDigit: '0',
      sex: 'male',
      expirationDate: '241125',
      expirationDateCheckDigit: '5',
      nationality: 'KWT',
      optional2: '19829871',
      lastName: 'ALSUWAILEM',
      firstName: 'ABDULLAH',
    });
  });
});
