const parse = require('../parse');

describe('parse TD1 pakistan', () => {
  it('PAK ID', () => {
    const data = [
      'I<PAK586586482<07416<<<<<<<<<<', '7107229M0909192PAK<<<<<<<<<<<2', 'ALAMGIR<<SHEIKH<MEHTAB<<<<<<<<',
    ];

    const result = parse(data);
    expect(result).toMatchObject({
      format: 'TD1',
      valid: true,
    });
    expect(result.fields).toStrictEqual({
      documentCode: 'I',
      issuingState: 'PAK',
      documentNumber: '5865864820741',
      documentNumberCheckDigit: '6',
      optional1: '',
      birthDate: '710722',
      birthDateCheckDigit: '9',
      sex: 'male',
      expirationDate: '090919',
      expirationDateCheckDigit: '2',
      nationality: 'PAK',
      optional2: '',
      compositeCheckDigit: '2',
      lastName: 'ALAMGIR',
      firstName: 'SHEIKH MEHTAB',
    });
  });

  it('PAK domestic ID', () => {
    const MRZ = [
      'I<PAKES0D10J744210121654659<<<', '9204270M2707141PAKAT7DMN<<<<<1', 'ZUBAIR<<USAMA<BIN<<<<<<<<<<<<<',
    ];

    const result = parse(MRZ);
    expect(result).toMatchObject({
      format: 'PAKISTAN_DOMESTIC_TD1',
      valid: true,
    });
    expect(result.fields).toStrictEqual({
      documentCode: 'I',
      issuingState: 'PAK',
      documentNumber: '4210121654659',
      optional1: '210121654659',
      birthDate: '920427',
      birthDateCheckDigit: '0',
      sex: 'male',
      expirationDate: '270714',
      expirationDateCheckDigit: '1',
      nationality: 'PAK',
      optional2: 'AT7DMN',
      lastName: 'ZUBAIR',
      firstName: 'USAMA BIN',
    });
  });
});
