const parse = require('../parse');

describe('parse TD3 with special chars in birthday', () => {
  it('day month are 00 00 in birthday', () => {
    const data = [
      'P<ISRMOR<<TSILA<<<<<<<<<<<<<<<<<<<<<<<<<<<<<', '32635050<4ISR5900002F28071110<1457986<6<<<22',
    ];

    const result = parse(data);

    expect(result.fields).toStrictEqual({
      documentCode: 'P',
      issuingState: 'ISR',
      lastName: 'MOR',
      firstName: 'TSILA',
      documentNumber: '32635050',
      documentNumberCheckDigit: '4',
      nationality: 'ISR',
      birthDate: '590000',
      birthDateCheckDigit: '2',
      sex: 'female',
      expirationDate: '280711',
      expirationDateCheckDigit: '1',
      optional1: '0 1457986 6',
      optionalFieldCheckDigit: '2',
      compositeCheckDigit: '2',
    });

    expect(result).toMatchObject({
      format: 'TD3',
      valid: true,
    });
  });

  it('XX XX as day/month in birthday', () => {
    const data = [
      'P<ISRDAVIDOWITZ<<TSIPORA<<<<<<<<<<<<<<<<<<<<', '22343892<7ISR49XXXX1F25072600<6524285<1<<<74',
    ];

    const result = parse(data);

    expect(result.fields).toStrictEqual({
      documentCode: 'P',
      issuingState: 'ISR',
      lastName: 'DAVIDOWITZ',
      firstName: 'TSIPORA',
      documentNumber: '22343892',
      documentNumberCheckDigit: '7',
      nationality: 'ISR',
      birthDate: '49XXXX',
      birthDateCheckDigit: '1',
      sex: 'female',
      expirationDate: '250726',
      expirationDateCheckDigit: '0',
      optional1: '0 6524285 1',
      optionalFieldCheckDigit: '7',
      compositeCheckDigit: '4',
    });

    expect(result).toMatchObject({
      format: 'TD3',
      valid: true,
    });
  });

  it('<< << as day/month in birthday', () => {
    const data = [
      'P<ISRDAVIDOWITZ<<TSIPORA<<<<<<<<<<<<<<<<<<<<', '22343892<7ISR49<<<<5F25072600<6524285<1<<<72',
    ];

    const result = parse(data);

    expect(result.fields).toStrictEqual({
      documentCode: 'P',
      issuingState: 'ISR',
      lastName: 'DAVIDOWITZ',
      firstName: 'TSIPORA',
      documentNumber: '22343892',
      documentNumberCheckDigit: '7',
      nationality: 'ISR',
      birthDate: '49<<<<',
      birthDateCheckDigit: '5',
      sex: 'female',
      expirationDate: '250726',
      expirationDateCheckDigit: '0',
      optional1: '0 6524285 1',
      optionalFieldCheckDigit: '7',
      compositeCheckDigit: '2',
    });

    expect(result).toMatchObject({
      format: 'TD3',
      valid: true,
    });
  });

  it('** ** as day/month in birthday', () => {
    const data = [
      'P<ISRDAVIDOWITZ<<TSIPORA<<<<<<<<<<<<<<<<<<<<', '22343892<7ISR49****9F25072600<6524285<1<<<70',
    ];

    const result = parse(data);

    expect(result.fields).toStrictEqual({
      documentCode: 'P',
      issuingState: 'ISR',
      lastName: 'DAVIDOWITZ',
      firstName: 'TSIPORA',
      documentNumber: '22343892',
      documentNumberCheckDigit: '7',
      nationality: 'ISR',
      birthDate: '49****',
      birthDateCheckDigit: '9',
      sex: 'female',
      expirationDate: '250726',
      expirationDateCheckDigit: '0',
      optional1: '0 6524285 1',
      optionalFieldCheckDigit: '7',
      compositeCheckDigit: '0',
    });

    expect(result).toMatchObject({
      format: 'TD3',
      valid: true,
    });
  });

  it('** ** as day/month in expiration date', () => {
    const data = [
      'P<ISRDAVIDOWITZ<<TSIPORA<<<<<<<<<<<<<<<<<<<<', '22343892<7ISR49****9F25****00<6524285<1<<<72',
    ];

    const result = parse(data);

    expect(result.fields).toStrictEqual({
      documentCode: 'P',
      issuingState: 'ISR',
      lastName: 'DAVIDOWITZ',
      firstName: 'TSIPORA',
      documentNumber: '22343892',
      documentNumberCheckDigit: '7',
      nationality: 'ISR',
      birthDate: '49****',
      birthDateCheckDigit: '9',
      sex: 'female',
      expirationDate: null,
      expirationDateCheckDigit: null,
      optional1: '0 6524285 1',
      optionalFieldCheckDigit: '7',
      compositeCheckDigit: null,
    });

    expect(result).toMatchObject({
      format: 'TD3',
      valid: false,
    });
  });
});
