const parse = require('../parse');

describe('parse URUGUAY id-card', () => {
  it('URUGUAY id-card - valid', () => {
    const data = [
      'I<URY00000QET8949186120<<<<<<<',
      '9902093<2207124URY170712<<<<<9',
      'ORTIZ<IOKASTORE<<FRANKJNAU<<<<',
    ];

    const result = parse(data);
    expect(result).toMatchObject({
      format: 'URUGUAY_TD1',
      valid: true,
    });
    expect(result.fields).toStrictEqual({
      documentCode: 'I',
      issuingState: 'URY',
      documentNumber: '49186120',
      documentNumberCheckDigit: '9',
      optional1: '49186120',
      birthDate: '990209',
      birthDateCheckDigit: '3',
      sex: 'nonspecified',
      expirationDate: '220712',
      expirationDateCheckDigit: '4',
      nationality: 'URY',
      optional2: '170712',
      compositeCheckDigit: '9',
      lastName: 'ORTIZ IOKASTORE',
      firstName: 'FRANKJNAU',
    });
  });

  it('URUGUAY id-card - valid2', () => {
    const data = [
      'I<URY00001WRC5537752412<<<<<<<',
      '7803277<3011113URY201111<<<<<1',
      'APARICIO<SASIAIN<<FREKY<RONEIN',
    ];

    const result = parse(data);
    expect(result).toMatchObject({
      format: 'URUGUAY_TD1',
      valid: true,
    });
    expect(result.fields).toStrictEqual({
      documentCode: 'I',
      issuingState: 'URY',
      documentNumber: '37752412',
      documentNumberCheckDigit: '5',
      optional1: '37752412',
      birthDate: '780327',
      birthDateCheckDigit: '7',
      sex: 'nonspecified',
      expirationDate: '301111',
      expirationDateCheckDigit: '3',
      nationality: 'URY',
      optional2: '201111',
      compositeCheckDigit: '1',
      lastName: 'APARICIO SASIAIN',
      firstName: 'FREKY RONEIN',
    });
  });
  it('URUGUAY id-card - valid3', () => {
    const data = [
      'I<URY00001M2G6314208111<<<<<<<',
      '6709121<2907103URY190710<<<<<2',
      'AGUERRE<PAJARES<<GAVRUELA<RANU',
    ];

    const result = parse(data);
    expect(result).toMatchObject({
      format: 'URUGUAY_TD1',
      valid: true,
    });
    expect(result.fields).toStrictEqual({
      documentCode: 'I',
      issuingState: 'URY',
      documentNumber: '14208111',
      documentNumberCheckDigit: '3',
      optional1: '14208111',
      birthDate: '670912',
      birthDateCheckDigit: '1',
      sex: 'nonspecified',
      expirationDate: '290710',
      expirationDateCheckDigit: '3',
      nationality: 'URY',
      optional2: '190710',
      compositeCheckDigit: '2',
      lastName: 'AGUERRE PAJARES',
      firstName: 'GAVRUELA RANU',
    });
  });
});
