const { SWISS_DRIVING_LICENSE } = require('./formats');
const { ValidationError } = require('./exceptions');

function validateMrzInput(lines) {
  const normalizedLines = typeof lines === 'string' ? lines.split(/[\r\n]+/) : lines;
  if (!Array.isArray(normalizedLines)) {
    throw new ValidationError('input must be an array or string');
  }
  for (const line of normalizedLines) {
    if (!line.match(/[A-Z0-9<]+/)) {
      throw new ValidationError('lines must be composed of only alphanumerical characters and "<"');
    }
  }
  return normalizedLines;
}

const getValidLines = (mrzLines, amountLines, amountCharacters, mrzType) => {
  if (mrzLines.length !== amountLines) {
    throw new ValidationError(`invalid number of lines: ${mrzLines.length}: Must be ${amountLines} for ${mrzType}`);
  }
  for (const line of mrzLines) {
    if (line.length !== amountCharacters) {
      throw new ValidationError(`invalid number of characters for line ${mrzLines.indexOf(line) + 1}: ${line.length}. Must be ${amountCharacters} for ${mrzType}`);
    }
  }
  return mrzLines;
};

const getValidSwissDriverLicenseLines = (mrzLines) => {
  if (mrzLines.length !== 3) {
    throw new ValidationError(`invalid number of lines: ${
      mrzLines.length
    }: Must be 3 for ${SWISS_DRIVING_LICENSE}`);
  }
  if (mrzLines[0].length !== 9) {
    throw new ValidationError(`invalid number of characters for line 1: ${
      mrzLines[0].length
    }. Must be 9 for ${SWISS_DRIVING_LICENSE}`);
  }
  if (mrzLines[1].length !== 30) {
    throw new ValidationError(`invalid number of characters for line 2: ${
      mrzLines[1].length
    }. Must be 30 for ${SWISS_DRIVING_LICENSE}`);
  }

  if (mrzLines[2].length !== 30) {
    throw new ValidationError(`invalid number of characters for line 3: ${
      mrzLines[2].length
    }. Must be 30 for ${SWISS_DRIVING_LICENSE}`);
  }
  return mrzLines;
};
module.exports = { getValidLines, validateMrzInput, getValidSwissDriverLicenseLines };
