const parseDocumentCode = require('../../parsers/euDrivingLicense/parseDocumentCode');
const parseState = require('../../parsers/parseState');
const parseDocumentNumber = require('../../parsers/euDrivingLicense/slovak/parseDocumentNumber');

const {
  documentCodeTemplate,
  issuingStateTemplate,
  documentNumberTemplate,
  documentNumberCheckDigitTemplate,
  birthDateTemplate,
  birthDateCheckDigitTemplate,
  compositeCheckDigitTemplate,
  expirationDateTemplate,
  expirationDateCheckDigitTemplate,
} = require('../fieldTemplates');
const createFieldParser = require('../createFieldParser');

module.exports = [
  {
    ...documentCodeTemplate,
    line: 0,
    start: 0,
    end: 1,
    parser: parseDocumentCode,
  },
  {
    ...issuingStateTemplate,
    line: 0,
    start: 2,
    end: 5,
    parser: parseState,
  },
  {
    ...documentNumberTemplate,
    line: 0,
    start: 5,
    end: 13,
    parser: parseDocumentNumber,
  },
  {
    ...documentNumberCheckDigitTemplate,
    line: 0,
    start: 14,
    end: 15,
    related: [
      {
        line: 0,
        start: 5,
        end: 13,
      },
    ],
  },
  {
    ...birthDateTemplate,
    line: 0,
    start: 15,
    end: 21,
  },
  {
    ...birthDateCheckDigitTemplate,
    line: 0,
    start: 21,
    end: 22,
    related: [
      {
        line: 0,
        start: 15,
        end: 21,
      },
    ],
  },
  {
    ...expirationDateTemplate,
    line: 0,
    start: 22,
    end: 28,
  },
  {
    ...expirationDateCheckDigitTemplate,
    line: 0,
    start: 28,
    end: 29,
    related: [
      {
        line: 0,
        start: 22,
        end: 28,
      },
    ],
  },
  {
    ...compositeCheckDigitTemplate,
    line: 0,
    start: 29,
    end: 30,
    related: [
      {
        line: 0,
        start: 0,
        end: 29,
      },
    ],
  },
].map(createFieldParser);
