const { GUATEMALA_TD1 } = require('../formats');

const { getValidLines } = require('../checkLines');
const getResult = require('../getResult');
const GuatemalaTD1Fields = require('./guatemalaTD1Fields');

const allDigitalIsValid = (details) => {
  const expirationDateCheckDigit = details.find((x) => x.field === 'expirationDateCheckDigit');
  const birthDateCheckDigit = details.find((x) => x.field === 'birthDateCheckDigit');
  const documentNumberCheckDigit = details.find((x) => x.field === 'documentNumberCheckDigit');
  return expirationDateCheckDigit?.valid
  && birthDateCheckDigit?.valid
  && documentNumberCheckDigit?.valid;
};

module.exports = function parseGuatemalaTD1(mrzLines) {
  const lines = getValidLines(mrzLines, 3, 30, GUATEMALA_TD1);

  const result = getResult(GUATEMALA_TD1, lines, GuatemalaTD1Fields);

  if (allDigitalIsValid(result.details)) {
    const compositeCheckDigit = result.details.find((x) => x.field === 'compositeCheckDigit');
    if (compositeCheckDigit && !compositeCheckDigit.valid) {
      compositeCheckDigit.value = compositeCheckDigit.ranges[0]?.raw || null;
      compositeCheckDigit.valid = true;
      result.fields.compositeCheckDigit = Number(compositeCheckDigit.value);
      result.valid = true;
    }
  }
  return result;
};
